@@ -1,15 +1,24 @@
-"""Top-level janitor API lives here."""
-try:
-    import janitor.xarray  # noqa: F401
-except ImportError:
-    pass
+"""Top-level janitor API lives here.
 
+Lazy loading used here to speed up imports.
+"""
+import lazy_loader as lazy
+
+
+from .accessors import *  # noqa: F403, F401
 from .functions import *  # noqa: F403, F401
 from .io import *  # noqa: F403, F401
 from .math import *  # noqa: F403, F401
 from .ml import get_features_targets as _get_features_targets
 from .utils import refactored_function
-from .accessors import *  # noqa: F403, F401
+
+
+_ = lazy.load("pandas_flavor")
+
+try:
+    jxr = lazy.load("janitor.xarray")  # noqa: F401
+except ImportError:
+    pass
 
 
 @refactored_function(
@@ -20,4 +29,4 @@ def get_features_targets(*args, **kwargs):
     return _get_features_targets(*args, **kwargs)
 
 
-__version__ = "0.23.1"
+__version__ = "0.24.0"
