@@ -2,7 +2,7 @@ from collections import defaultdict
 from itertools import zip_longest, chain
 import re
 import warnings
-from typing import Optional, Pattern, Union, Callable, Generator
+from typing import Optional, Pattern, Union, Callable
 
 import numpy as np
 import pandas as pd
@@ -10,12 +10,12 @@ import pandas_flavor as pf
 from pandas.api.types import (
     is_list_like,
     is_string_dtype,
+    is_categorical_dtype,
 )
-from pandas.core.construction import extract_array
 from pandas.core.dtypes.concat import concat_compat
 
 from janitor.functions.utils import (
-    _select_column_names,
+    _select_index,
     _computations_expand_grid,
 )
 from janitor.utils import check
@@ -32,6 +32,7 @@ def pivot_longer(
     names_sep: Optional[Union[str, Pattern]] = None,
     names_pattern: Optional[Union[list, tuple, str, Pattern]] = None,
     names_transform: Optional[Union[str, Callable, dict]] = None,
+    dropna: bool = False,
     sort_by_appearance: Optional[bool] = False,
     ignore_index: Optional[bool] = True,
 ) -> pd.DataFrame:
@@ -51,7 +52,7 @@ def pivot_longer(
     row axis.
 
     Column selection in `index` and `column_names` is possible using the
-    [`select_columns`][janitor.functions.select_columns.select_columns] syntax.
+    [`select_columns`][janitor.functions.select.select_columns] syntax.
 
     Example:
 
@@ -219,6 +220,13 @@ def pivot_longer(
         7   Austin    Texas  Watermelon      99   None     NaN
         8   Hoover  Alabama  Watermelon      43   None     NaN
 
+
+    !!! abstract "Version Changed"
+
+        - 0.24.0
+            - Added `dropna` parameter.
+
+
     :param df: A pandas DataFrame.
     :param index: Name(s) of columns to use as identifier variables.
         Should be either a single column name, or a list/tuple of
@@ -258,8 +266,10 @@ def pivot_longer(
         arguments must match.
         `names_pattern` does not work with MultiIndex columns.
     :param names_transform: Use this option to change the types of columns that
-        have been transformed to rows. This does not applies to the values columns.
-        Accepts a string, a callable, or a dictionary that is acceptable by `pd.astype`.
+        have been transformed to rows. This does not applies to the values' columns.
+        Accepts any argument that is acceptable by `pd.astype`.
+    :param dropna: Determines whether or not to drop nulls
+        from the values columns. Default is `False`.
     :param sort_by_appearance: Default `False`. Boolean value that determines
         the final look of the DataFrame. If `True`, the unpivoted DataFrame
         will be stacked in order of first appearance.
@@ -284,6 +294,7 @@ def pivot_longer(
         names_sep,
         names_pattern,
         names_transform,
+        dropna,
         sort_by_appearance,
         ignore_index,
     ) = _data_checks_pivot_longer(
@@ -296,6 +307,7 @@ def pivot_longer(
         names_sep,
         names_pattern,
         names_transform,
+        dropna,
         sort_by_appearance,
         ignore_index,
     )
@@ -309,6 +321,7 @@ def pivot_longer(
         names_sep,
         names_pattern,
         names_transform,
+        dropna,
         sort_by_appearance,
         ignore_index,
     )
@@ -324,6 +337,7 @@ def _data_checks_pivot_longer(
     names_sep,
     names_pattern,
     names_transform,
+    dropna,
     sort_by_appearance,
     ignore_index,
 ) -> tuple:
@@ -375,26 +389,44 @@ def _data_checks_pivot_longer(
                 "when the columns are a MultiIndex."
             )
 
+    is_multi_index = isinstance(df.columns, pd.MultiIndex)
+    indices = None
     if column_names is not None:
-        if is_list_like(column_names) and (
-            not isinstance(column_names, tuple)
-        ):
-            column_names = [*column_names]
-        column_names = _select_column_names(column_names, df)
+        if is_multi_index:
+            column_names = _check_tuples_multiindex(
+                df.columns, column_names, "column_names"
+            )
+        else:
+            if is_list_like(column_names):
+                column_names = list(column_names)
+            indices = _select_index(column_names, df, axis="columns")
+            column_names = df.columns[indices]
+            if not is_list_like(column_names):
+                column_names = [column_names]
+            else:
+                column_names = list(column_names)
 
     if index is not None:
-        if is_list_like(index) and (not isinstance(index, tuple)):
-            index = [*index]
-        index = _select_column_names(index, df)
-
-    if not index:
-        if not column_names:
-            column_names = [*df.columns]
+        if is_multi_index:
+            index = _check_tuples_multiindex(df.columns, index, "index")
         else:
-            index = [*df.columns.difference(column_names, sort=False)]
+            if is_list_like(index):
+                index = list(index)
+            indices = _select_index(index, df, axis="columns")
+            index = df.columns[indices]
+            if not is_list_like(index):
+                index = [index]
+            else:
+                index = list(index)
+
+    if index is None:
+        if column_names is None:
+            column_names = df.columns.tolist()
+        else:
+            index = df.columns.difference(column_names, sort=False).tolist()
     else:
-        if not column_names:
-            column_names = [*df.columns.difference(index, sort=False)]
+        if column_names is None:
+            column_names = df.columns.difference(index, sort=False).tolist()
 
     len_names_to = 0
     if names_to is not None:
@@ -526,8 +558,7 @@ def _data_checks_pivot_longer(
                     "index parameter. Kindly provide unique label(s)."
                 )
 
-    if names_transform:
-        check("names_transform", names_transform, [str, Callable, dict])
+    check("dropna", dropna, [bool])
 
     check("sort_by_appearance", sort_by_appearance, [bool])
 
@@ -570,6 +601,7 @@ def _data_checks_pivot_longer(
         names_sep,
         names_pattern,
         names_transform,
+        dropna,
         sort_by_appearance,
         ignore_index,
     )
@@ -583,7 +615,8 @@ def _computations_pivot_longer(
     values_to: Union[list, str, None],
     names_sep: Union[str, Pattern],
     names_pattern: Union[list, tuple, str, Pattern],
-    names_transform: Union[str, Callable, dict],
+    names_transform: Union[str, Callable, dict, None],
+    dropna: bool,
     sort_by_appearance: bool,
     ignore_index: bool,
 ) -> pd.DataFrame:
@@ -599,24 +632,22 @@ def _computations_pivot_longer(
     # since we already have made a copy of the original df
 
     if not column_names:
-        return df.rename_axis(columns=None)
+        return df
 
     if index:
-        index = {
-            name: extract_array(df[name], extract_numpy=True) for name in index
-        }
+        index = {name: df[name]._values for name in index}
 
+    if len(column_names) != len(set(column_names)):
+        column_names = pd.unique(column_names)
     df = df.loc[:, column_names]
 
-    len_index = len(df)
-
     if all((names_pattern is None, names_sep is None)):
         return _base_melt(
             df=df,
             index=index,
-            len_index=len_index,
             values_to=values_to,
             names_transform=names_transform,
+            dropna=dropna,
             sort_by_appearance=sort_by_appearance,
             ignore_index=ignore_index,
         )
@@ -625,11 +656,11 @@ def _computations_pivot_longer(
         return _pivot_longer_names_sep(
             df=df,
             index=index,
-            len_index=len_index,
             names_to=names_to,
             names_sep=names_sep,
             names_transform=names_transform,
             values_to=values_to,
+            dropna=dropna,
             sort_by_appearance=sort_by_appearance,
             ignore_index=ignore_index,
         )
@@ -638,11 +669,11 @@ def _computations_pivot_longer(
         return _pivot_longer_names_pattern_str(
             df=df,
             index=index,
-            len_index=len_index,
             names_to=names_to,
             names_pattern=names_pattern,
             names_transform=names_transform,
             values_to=values_to,
+            dropna=dropna,
             sort_by_appearance=sort_by_appearance,
             ignore_index=ignore_index,
         )
@@ -650,10 +681,10 @@ def _computations_pivot_longer(
     return _pivot_longer_names_pattern_sequence(
         df=df,
         index=index,
-        len_index=len_index,
         names_to=names_to,
         names_pattern=names_pattern,
         names_transform=names_transform,
+        dropna=dropna,
         sort_by_appearance=sort_by_appearance,
         values_to=values_to,
         ignore_index=ignore_index,
@@ -663,10 +694,10 @@ def _computations_pivot_longer(
 def _pivot_longer_names_pattern_sequence(
     df: pd.DataFrame,
     index: Union[dict, None],
-    len_index: int,
     names_to: list,
     names_pattern: Union[list, tuple],
-    names_transform: Union[str, Callable, dict],
+    names_transform: Union[str, Callable, dict, None],
+    dropna: bool,
     sort_by_appearance: bool,
     values_to: Union[str, list, tuple],
     ignore_index: bool,
@@ -684,17 +715,17 @@ def _pivot_longer_names_pattern_sequence(
                 "column labels assigned to the dataframe's index parameter. "
                 "Kindly use unique labels."
             )
-    outcome = df.columns
+    values = df.columns
 
     mapping = [
-        outcome.str.contains(regex, na=False, regex=True)
+        values.str.contains(regex, na=False, regex=True)
         for regex in names_pattern
     ]
 
-    outcome = (arr.any() for arr in mapping)
+    values = (arr.any() for arr in mapping)
     # within each match, check the individual matches
     # and raise an error if any is False
-    for position, boolean in enumerate(outcome):
+    for position, boolean in enumerate(values):
         if not boolean.item():
             raise ValueError(
                 "No match was returned for the regex "
@@ -702,69 +733,61 @@ def _pivot_longer_names_pattern_sequence(
             )
 
     if values_to_is_a_sequence:
-        mapping, values = np.select(mapping, values_to, None), np.select(
+        mapping, outcome = np.select(mapping, values_to, None), np.select(
             mapping, names_to, None
         )
     else:
         mapping = np.select(mapping, names_to, None)
 
     # only matched columns are retained
-    outcome = pd.notna(mapping)
-    df = df.loc[:, outcome]
-    mapping = mapping[outcome]
+    values = pd.notna(mapping)
+    df = df.loc[:, values]
+    mapping = mapping[values]
     if values_to_is_a_sequence:
         names_to = zip(names_to, values_to)
         names_to = [*chain.from_iterable(names_to)]
         if index:
             names_to = [*index] + names_to
-        values = values[outcome]
+        outcome = outcome[values]
         arr = defaultdict(list)
-        for label, name in zip(values, df.columns):
+        for label, name in zip(outcome, df.columns):
             arr[label].append(name)
-        values = arr.keys()
+        outcome = arr.keys()
         arr = (entry for _, entry in arr.items())
         arr = zip(*zip_longest(*arr))
         arr = map(pd.Series, arr)
-        values = zip(values, arr)
-        if names_transform:
-            values = _names_transform(
-                names_transform, is_dataframe=False, values=values
-            )
-        values = {
-            name: extract_array(arr, extract_numpy=True).repeat(len_index)
-            for name, arr in values
-        }
+        outcome = dict(zip(outcome, arr))
     else:
-        values = {}
+        outcome = None
+        names_to = None
 
     mapping = pd.Series(mapping)
-    outcome, group_max = _headers_single_series(df=df, mapping=mapping)
+    values, group_max = _headers_single_series(df=df, mapping=mapping)
 
     df = _final_frame_longer(
         df=df,
-        len_index=len_index,
         reps=group_max,
         index=index,
         outcome=outcome,
         values=values,
+        names_to=names_to,
+        dropna=dropna,
+        names_transform=names_transform,
         sort_by_appearance=sort_by_appearance,
         ignore_index=ignore_index,
     )
 
-    if values_to_is_a_sequence:
-        df = df.loc[:, names_to]
-
     return df
 
 
 def _pivot_longer_names_pattern_str(
     df: pd.DataFrame,
-    index: Union[list, None],
-    len_index: int,
+    index: Union[dict, None],
     names_to: list,
     names_pattern: Union[str, Pattern],
     names_transform: bool,
     values_to: str,
+    dropna: bool,
     sort_by_appearance: bool,
     ignore_index: bool,
 ) -> pd.DataFrame:
@@ -795,9 +818,9 @@ def _pivot_longer_names_pattern_str(
         return _base_melt(
             df=df,
             index=index,
-            len_index=len_index,
             values_to=values_to,
             names_transform=names_transform,
+            dropna=dropna,
             sort_by_appearance=sort_by_appearance,
             ignore_index=ignore_index,
         )
@@ -805,10 +828,10 @@ def _pivot_longer_names_pattern_str(
     return _pivot_longer_dot_value(
         df=df,
         index=index,
-        len_index=len_index,
         sort_by_appearance=sort_by_appearance,
         ignore_index=ignore_index,
         names_to=names_to,
+        dropna=dropna,
         names_transform=names_transform,
         mapping=mapping,
     )
@@ -816,12 +839,12 @@ def _pivot_longer_names_pattern_str(
 
 def _pivot_longer_names_sep(
     df: pd.DataFrame,
-    index: list,
-    len_index: int,
+    index: Union[dict, None],
     names_to: list,
     names_sep: Union[str, Pattern],
     values_to: str,
     names_transform: bool,
+    dropna: bool,
     sort_by_appearance: bool,
     ignore_index: bool,
 ) -> pd.DataFrame:
@@ -853,9 +876,9 @@ def _pivot_longer_names_sep(
         return _base_melt(
             df=df,
             index=index,
-            len_index=len_index,
             values_to=values_to,
             names_transform=names_transform,
+            dropna=dropna,
             sort_by_appearance=sort_by_appearance,
             ignore_index=ignore_index,
         )
@@ -863,10 +886,10 @@ def _pivot_longer_names_sep(
     return _pivot_longer_dot_value(
         df=df,
         index=index,
-        len_index=len_index,
         sort_by_appearance=sort_by_appearance,
         ignore_index=ignore_index,
         names_to=names_to,
+        dropna=dropna,
         names_transform=names_transform,
         mapping=mapping,
     )
@@ -875,9 +898,9 @@ def _pivot_longer_names_sep(
 def _base_melt(
     df: pd.DataFrame,
     index: Union[dict, None],
-    len_index: int,
     values_to: str,
     names_transform: Union[str, Callable, dict, None],
+    dropna: bool,
     sort_by_appearance: bool,
     ignore_index: bool,
 ) -> pd.DataFrame:
@@ -887,28 +910,29 @@ def _base_melt(
 
     columns = df.columns
     reps = len(columns)
-    outcome = (
-        (name, columns.get_level_values(name)) for name in columns.names
-    )
-    if names_transform:
-        outcome = _names_transform(
-            names_transform, is_dataframe=False, values=outcome
-        )
-    outcome = {
-        name: extract_array(arr, extract_numpy=True).repeat(len_index)
-        for name, arr in outcome
-    }
+    outcome = {name: columns.get_level_values(name) for name in columns.names}
 
-    values = [extract_array(arr, extract_numpy=True) for _, arr in df.items()]
-    values = {values_to: concat_compat(values)}
+    # offers a fast route
+    # while still returning the underlying array
+    # which could be an extension array
+    # thus helping in preserving dtypes where possible
+    if df._mgr.any_extension_types:
+        values = df._mgr
+        values = [values.iget_values(i) for i in range(df.columns.size)]
+        values = concat_compat(values)
+    else:
+        values = df._values.ravel(order="F")
+    values = {values_to: values}
 
     return _final_frame_longer(
         df=df,
-        len_index=len_index,
         reps=reps,
         index=index,
         outcome=outcome,
         values=values,
+        names_to=None,
+        dropna=dropna,
+        names_transform=names_transform,
         sort_by_appearance=sort_by_appearance,
         ignore_index=ignore_index,
     )
@@ -917,10 +941,10 @@ def _base_melt(
 def _pivot_longer_dot_value(
     df: pd.DataFrame,
     index: Union[dict, None],
-    len_index: int,
     sort_by_appearance: bool,
     ignore_index: bool,
     names_to: list,
+    dropna: bool,
     names_transform: Union[str, Callable, dict, None],
     mapping: pd.DataFrame,
 ) -> pd.DataFrame:
@@ -933,8 +957,15 @@ def _pivot_longer_dot_value(
     """
     if np.count_nonzero(mapping.columns == ".value") > 1:
         outcome = mapping.pop(".value")
-        outcome = outcome.agg("".join, axis=1)
-        mapping[".value"] = outcome
+        out = outcome.iloc[:, 0]
+        # for loop preferred over agg
+        # primarily for speed
+        # if the column is a large array
+        # direct addition is surprisingly faster than
+        # the convenient agg(','.join, axis = 1) option
+        for _, val in outcome.iloc[:, 1:].items():
+            out += val
+        mapping[".value"] = out
 
     exclude = {
         word
@@ -963,14 +994,15 @@ def _pivot_longer_dot_value(
     if len(mapping.columns) == 1:
         mapping = mapping.iloc[:, 0]
         values, group_max = _headers_single_series(df=df, mapping=mapping)
-        outcome = {}
+        outcome = None
+
     else:
         # For multiple columns, the labels in `.value`
         # should have every value in other
         # and in the same order
         # reindex ensures that, after getting a MultiIndex.from_product
         other = [entry for entry in names_to if entry != ".value"]
-        columns = [*mapping.columns]
+        columns = mapping.columns.tolist()
         others = mapping.loc[:, other].drop_duplicates()
         outcome = mapping.loc[:, ".value"].unique()
         if not mapping.duplicated().any(axis=None):
@@ -979,7 +1011,7 @@ def _pivot_longer_dot_value(
         else:
             columns.append("".join(columns))
             cumcount = mapping.groupby(
-                [*mapping.columns], sort=False, observed=True
+                mapping.columns.tolist(), sort=False, observed=True
             ).cumcount()
             df.columns = [arr for _, arr in mapping.items()] + [cumcount]
             indexer = {
@@ -988,28 +1020,23 @@ def _pivot_longer_dot_value(
                 "cumcount": cumcount.unique(),
             }
         indexer = _computations_expand_grid(indexer)
+
         indexer.columns = columns
         df = df.reindex(columns=indexer)
         df.columns = df.columns.get_level_values(".value")
         values = _dict_from_grouped_names(df=df)
         outcome = indexer.loc[indexer[".value"] == outcome[0], other]
         group_max = len(outcome)
-        if names_transform:
-            outcome = _names_transform(
-                names_transform, is_dataframe=True, values=outcome
-            )
-        outcome = {
-            name: extract_array(arr, extract_numpy=True).repeat(len_index)
-            for name, arr in outcome.items()
-        }
 
     return _final_frame_longer(
         df=df,
-        len_index=len_index,
         reps=group_max,
         index=index,
         outcome=outcome,
         values=values,
+        names_to=None,
+        dropna=dropna,
+        names_transform=names_transform,
         sort_by_appearance=sort_by_appearance,
         ignore_index=ignore_index,
     )
@@ -1047,7 +1074,8 @@ def _headers_single_series(df: pd.DataFrame, mapping: pd.Series) -> tuple:
         df.columns = [mapping, positions]
         indexer = group_size.index, np.arange(group_max)
         indexer = pd.MultiIndex.from_product(indexer)
-        df = df.reindex(columns=indexer).droplevel(axis=1, level=1)
+        df = df.reindex(columns=indexer)
+        df.columns = df.columns.get_level_values(0)
     else:
         df.columns = mapping
     outcome = _dict_from_grouped_names(df=df)
@@ -1062,127 +1090,87 @@ def _dict_from_grouped_names(df: pd.DataFrame) -> dict:
     """
     outcome = defaultdict(list)
     for num, name in enumerate(df.columns):
-        arr = df.iloc[:, num]
-        arr = extract_array(arr, extract_numpy=True)
+        arr = df.iloc[:, num]._values
         outcome[name].append(arr)
     return {name: concat_compat(arr) for name, arr in outcome.items()}
 
 
-def _names_transform(
-    names_transform, is_dataframe, values
-) -> Union[pd.DataFrame, Generator]:
-    """
-    Convert column type using names_transform.
-
-    If is_dataframe (values is a DataFrame),
-    then astype is applied directly; otherwise an iteration.
-
-    Returns either a DataFrame or a generator.
-    """
-    if is_dataframe:
-        return values.astype(names_transform)
-    if isinstance(names_transform, dict):
-        outcome = (
-            (key, arr.astype(names_transform[key]))
-            for key, arr in values
-            if key in names_transform
-        )
-    else:
-        outcome = ((key, arr.astype(names_transform)) for key, arr in values)
-    return outcome
-
-
-def _sort_by_appearance_for_melt(
-    df: pd.DataFrame, len_index: int
-) -> pd.DataFrame:
-    """
-    This function sorts the resulting dataframe by appearance,
-    via the `sort_by_appearance` parameter in `computations_pivot_longer`.
-
-    A dataframe that is sorted by appearance is returned.
-    """
-
-    # explanation here to help future me :)
-
-    # if the height of the new dataframe
-    # is the same as the height of the original dataframe,
-    # then there is no need to sort by appearance
-    length_check = any((len_index == 1, len_index == len(df)))
-
-    # pd.melt flips the columns into vertical positions
-    # it `tiles` the index during the flipping
-    # example:
-
-    #          first last  height  weight
-    # person A  John  Doe     5.5     130
-    #        B  Mary   Bo     6.0     150
-
-    # melting the dataframe above yields:
-    # df.melt(['first', 'last'])
-
-    #   first last variable  value
-    # 0  John  Doe   height    5.5
-    # 1  Mary   Bo   height    6.0
-    # 2  John  Doe   weight  130.0
-    # 3  Mary   Bo   weight  150.0
-
-    # sort_by_appearance `untiles` the index
-    # and keeps all `John` before all `Mary`
-    # since `John` appears first in the original dataframe:
-
-    #   first last variable  value
-    # 0  John  Doe   height    5.5
-    # 1  John  Doe   weight  130.0
-    # 2  Mary   Bo   height    6.0
-    # 3  Mary   Bo   weight  150.0
-
-    # to get to this second form, which is sorted by appearance,
-    # get the lengths of the dataframe
-    # before and after it is melted
-    # for the example above, the length before melting is 2
-    # and after -> 4.
-    # reshaping allows us to track the original positions
-    # in the previous dataframe ->
-    # np.reshape([0,1,2,3], (-1, 2)) becomes
-    # array([[0, 1],
-    #        [2, 3]])
-    # ravel, with the Fortran order (`F`) ensures the John's are aligned
-    # before the Mary's -> [0, 2, 1, 3]
-    # the flattened array is then passed to `take`
-    if not length_check:
-        index_sorter = np.arange(len(df))
-        index_sorter = np.reshape(index_sorter, (-1, len_index))
-        index_sorter = index_sorter.ravel(order="F")
-        df = df.take(index_sorter)
-
-    return df
-
-
 def _final_frame_longer(
     df: pd.DataFrame,
-    len_index: int,
     reps: int,
     index: Union[dict, None],
     outcome: dict,
     values: dict,
+    names_to: Union[list, None],
+    dropna: bool,
+    names_transform: Union[str, Callable, dict, None],
     sort_by_appearance: bool,
     ignore_index: bool,
 ) -> pd.DataFrame:
     """
     Build final dataframe for pivot_longer.
     """
+    len_index = len(df)
     indexer = np.tile(np.arange(len_index), reps)
+
+    if (names_transform is not None) & (outcome is not None):
+        if isinstance(names_transform, dict):
+            outcome = {
+                key: arr.astype(names_transform[key], copy=False)
+                for key, arr in outcome.items()
+                if key in names_transform
+            }
+        else:
+            outcome = {
+                key: arr.astype(names_transform, copy=False)
+                for key, arr in outcome.items()
+            }
+    if outcome is not None:
+        outcome = {
+            name: arr._values.repeat(len_index)
+            for name, arr in outcome.items()
+        }
+    if dropna:
+        if len(values) == 1:
+            key = next(iter(values))
+            any_nulls = pd.isna(values[key])
+        else:
+            any_nulls = [pd.isna(arr) for _, arr in values.items()]
+            any_nulls = np.logical_and.reduce(any_nulls)
+        if any_nulls.any():
+            values = {name: arr[~any_nulls] for name, arr in values.items()}
+            indexer = indexer[~any_nulls]
+            if outcome is not None:
+                outcome = {
+                    name: arr[~any_nulls] for name, arr in outcome.items()
+                }
+
+    any_nulls = None
+
     df_index = df.index[indexer]
     if index:
         index = {name: arr[indexer] for name, arr in index.items()}
     else:
         index = {}
+    if outcome is None:
+        outcome = {}
+
     df = {**index, **outcome, **values}
 
+    if names_to:
+        # relevant if values_to is a sequence
+        # helps with reordering the data
+        # and is much faster than having to use `.loc`
+        # after the DataFrame is created
+        df = {name: df[name] for name in names_to}
+
     df = pd.DataFrame(df, copy=False, index=df_index)
+    df_index = None
 
     if sort_by_appearance:
-        df = _sort_by_appearance_for_melt(df=df, len_index=len_index)
+        indexer = indexer.argsort(kind="stable")
+        df = df.take(indexer)
+    indexer = None
 
     if ignore_index:
         df.index = range(len(df))
@@ -1202,6 +1190,9 @@ def pivot_wider(
     flatten_levels: Optional[bool] = True,
     names_sep: str = "_",
     names_glue: str = None,
+    reset_index: bool = True,
+    names_expand: bool = False,
+    index_expand: bool = False,
 ) -> pd.DataFrame:
     """
     Reshapes data from *long* to *wide* form.
@@ -1215,7 +1206,7 @@ def pivot_wider(
 
     Column selection in `index`, `names_from` and `values_from`
     is possible using the
-    [`select_columns`][janitor.functions.select_columns.select_columns] syntax.
+    [`select_columns`][janitor.functions.select.select_columns] syntax.
 
     A ValueError is raised if the combination
     of the `index` and `names_from` is not unique.
@@ -1226,6 +1217,7 @@ def pivot_wider(
     at the start of each label in the columns.
 
 
+
     Example:
 
         >>> import pandas as pd
@@ -1274,6 +1266,13 @@ def pivot_wider(
         0  5.5       20       25       30       37
         1  6.1       22       18       19       29
 
+
+    !!! abstract "Version Changed"
+
+        - 0.24.0
+            - Added `reset_index`, `names_expand` and `index_expand` parameters.
+
+
     :param df: A pandas DataFrame.
     :param index: Name(s) of columns to use as identifier variables.
         It should be either a single column name, or a list of column names.
@@ -1296,12 +1295,19 @@ def pivot_wider(
         and uses python's `str.format_map` under the hood.
         Simply create the string template,
         using the column labels in `names_from`,
-        and special `_value` as a placeholder
-        if there are multiple `values_from`.
+        and special `_value` as a placeholder for `values_from`.
         Applicable only if `flatten_levels` is `True`.
+    :param reset_index: Determines whether to restore `index`
+        as a column/columns. Applicable only if `index` is provided,
+        and `flatten_levels` is `True`. Default is `True`.
+    :param names_expand: Expand columns to show all the categories.
+        Applies only if `names_from` is a categorical column.
+        Default is `False`.
+    :param index_expand: Expand the index to show all the categories.
+        Applies only if `index` is a categorical column. Default is `False`.
     :returns: A pandas DataFrame that has been unpivoted from long to wide
         form.
-    """
+    """  # noqa: E501
 
     df = df.copy()
 
@@ -1313,6 +1319,9 @@ def pivot_wider(
         flatten_levels,
         names_sep,
         names_glue,
+        reset_index,
+        names_expand,
+        index_expand,
     )
 
 
@@ -1324,6 +1333,9 @@ def _computations_pivot_wider(
     flatten_levels: Optional[bool] = True,
     names_sep: str = "_",
     names_glue: str = None,
+    reset_index: bool = True,
+    names_expand: bool = False,
+    index_expand: bool = False,
 ) -> pd.DataFrame:
     """
     This is the main workhorse of the `pivot_wider` function.
@@ -1343,6 +1355,9 @@ def _computations_pivot_wider(
         flatten_levels,
         names_sep,
         names_glue,
+        reset_index,
+        names_expand,
+        index_expand,
     ) = _data_checks_pivot_wider(
         df,
         index,
@@ -1351,30 +1366,54 @@ def _computations_pivot_wider(
         flatten_levels,
         names_sep,
         names_glue,
+        reset_index,
+        names_expand,
+        index_expand,
     )
-    if flatten_levels:
-        # check dtype of `names_from` is string
-        names_from_all_strings = (
-            df.filter(names_from).agg(is_string_dtype).all().item()
-        )
-
-        # check dtype of columns
-        column_dtype = is_string_dtype(df.columns)
 
     df = df.pivot(  # noqa: PD010
         index=index, columns=names_from, values=values_from
     )
 
-    # an empty df is likely because
-    # there is no `values_from`
+    indexer = df.index
+    if index_expand and index:
+        any_categoricals = (indexer.get_level_values(name) for name in index)
+        any_categoricals = any(map(is_categorical_dtype, any_categoricals))
+        if any_categoricals:
+            indexer = _expand(indexer, retain_categories=True)
+            df = df.reindex(index=indexer)
+
+    indexer = df.columns
+    if names_expand:
+        any_categoricals = (
+            indexer.get_level_values(name) for name in names_from
+        )
+        any_categoricals = any(map(is_categorical_dtype, any_categoricals))
+        if any_categoricals:
+            retain_categories = True
+            if flatten_levels & (
+                (names_glue is not None)
+                | isinstance(indexer, pd.MultiIndex)
+                | ((index is not None) & reset_index)
+            ):
+                retain_categories = False
+            indexer = _expand(indexer, retain_categories=retain_categories)
+            df = df.reindex(columns=indexer)
+
+    indexer = None
     if any((df.empty, not flatten_levels)):
         return df
 
     if isinstance(df.columns, pd.MultiIndex):
-        if (not names_from_all_strings) or (not column_dtype):
-            new_columns = [tuple(map(str, entry)) for entry in df]
-        else:
-            new_columns = [entry for entry in df]
+        new_columns = df.columns
+        all_strings = (
+            new_columns.get_level_values(num)
+            for num in range(new_columns.nlevels)
+        )
+        all_strings = all(map(is_string_dtype, all_strings))
+        if not all_strings:
+            new_columns = (tuple(map(str, entry)) for entry in new_columns)
+
         if names_glue is not None:
             if ("_value" in names_from) and (None in df.columns.names):
                 warnings.warn(
@@ -1407,24 +1446,18 @@ def _computations_pivot_wider(
 
         df.columns = new_columns
     else:
-        if (not names_from_all_strings) or (not column_dtype):
-            df.columns = df.columns.astype(str)
         if names_glue is not None:
             try:
                 df.columns = [
                     names_glue.format_map({names_from[0]: entry})
-                    for entry in df
+                    for entry in df.columns
                 ]
             except KeyError as error:
                 raise KeyError(
                     f"{error} is not a column label in names_from."
                 ) from error
 
-    # if columns are of category type
-    # this returns columns to object dtype
-    # also, resetting index with category columns is not possible
-    df.columns = [*df.columns]
-    if index:
+    if index and reset_index:
         df = df.reset_index()
 
     if df.columns.names:
@@ -1441,6 +1474,9 @@ def _data_checks_pivot_wider(
     flatten_levels,
     names_sep,
     names_glue,
+    reset_index,
+    names_expand,
+    index_expand,
 ):
 
     """
@@ -1451,26 +1487,74 @@ def _data_checks_pivot_wider(
     checking happens.
     """
 
+    is_multi_index = isinstance(df.columns, pd.MultiIndex)
+    indices = None
     if index is not None:
-        if is_list_like(index):
-            index = [*index]
-        index = _select_column_names(index, df)
+        if is_multi_index:
+            if not isinstance(index, list):
+                raise TypeError(
+                    "For a MultiIndex column, pass a list of tuples "
+                    "to the index argument."
+                )
+            index = _check_tuples_multiindex(df.columns, index, "index")
+        else:
+            if is_list_like(index):
+                index = list(index)
+            indices = _select_index(index, df, axis="columns")
+            index = df.columns[indices]
+            if not is_list_like(index):
+                index = [index]
+            else:
+                index = list(index)
 
     if names_from is None:
         raise ValueError(
             "pivot_wider() is missing 1 required argument: 'names_from'"
         )
 
-    if is_list_like(names_from):
-        names_from = [*names_from]
-    names_from = _select_column_names(names_from, df)
+    if is_multi_index:
+        if not isinstance(names_from, list):
+            raise TypeError(
+                "For a MultiIndex column, pass a list of tuples "
+                "to the names_from argument."
+            )
+        names_from = _check_tuples_multiindex(
+            df.columns, names_from, "names_from"
+        )
+    else:
+        if is_list_like(names_from):
+            names_from = list(names_from)
+        indices = _select_index(names_from, df, axis="columns")
+        names_from = df.columns[indices]
+        if not is_list_like(names_from):
+            names_from = [names_from]
+        else:
+            names_from = list(names_from)
 
     if values_from is not None:
-        if is_list_like(values_from):
-            values_from = [*values_from]
-        values_from = _select_column_names(values_from, df)
-        if len(values_from) == 1:
-            values_from = values_from[0]
+        if is_multi_index:
+            if not isinstance(values_from, list):
+                raise TypeError(
+                    "For a MultiIndex column, pass a list of tuples "
+                    "to the values_from argument."
+                )
+            out = _check_tuples_multiindex(
+                df.columns, values_from, "values_from"
+            )
+        else:
+            if is_list_like(values_from):
+                values_from = list(values_from)
+            indices = _select_index(values_from, df, axis="columns")
+            out = df.columns[indices]
+            if not is_list_like(out):
+                out = [out]
+            else:
+                out = list(out)
+        # hack to align with pd.pivot
+        if values_from == out[0]:
+            values_from = out[0]
+        else:
+            values_from = out
 
     check("flatten_levels", flatten_levels, [bool])
 
@@ -1480,6 +1564,10 @@ def _data_checks_pivot_wider(
     if names_glue is not None:
         check("names_glue", names_glue, [str])
 
+    check("reset_index", reset_index, [bool])
+    check("names_expand", names_expand, [bool])
+    check("index_expand", index_expand, [bool])
+
     return (
         df,
         index,
@@ -1488,4 +1576,75 @@ def _data_checks_pivot_wider(
         flatten_levels,
         names_sep,
         names_glue,
+        reset_index,
+        names_expand,
+        index_expand,
     )
+
+
+def _expand(indexer, retain_categories):
+    """
+    Expand Index to all categories.
+    Applies to categorical index, and used
+    in _computations_pivot_wider for scenarios where
+    names_expand and/or index_expand is True.
+    Categories are preserved where possible.
+    If `retain_categories` is False, a fastpath is taken
+    to generate all possible combinations.
+
+    Returns an Index.
+    """
+    if indexer.nlevels > 1:
+        names = indexer.names
+        if not retain_categories:
+            indexer = pd.MultiIndex.from_product(indexer.levels, names=names)
+        else:
+            indexer = [
+                indexer.get_level_values(n) for n in range(indexer.nlevels)
+            ]
+            indexer = [
+                pd.Categorical(
+                    values=arr.categories,
+                    categories=arr.categories,
+                    ordered=arr.ordered,
+                )
+                if is_categorical_dtype(arr)
+                else arr.unique()
+                for arr in indexer
+            ]
+            indexer = pd.MultiIndex.from_product(indexer, names=names)
+
+    else:
+        if not retain_categories:
+            indexer = indexer.categories
+        else:
+            indexer = pd.Categorical(
+                values=indexer.categories,
+                categories=indexer.categories,
+                ordered=indexer.ordered,
+            )
+    return indexer
+
+
+def _check_tuples_multiindex(indexer, args, param):
+    """
+    Check entries for tuples,
+    if indexer is a MultiIndex.
+
+    Returns a list of tuples.
+    """
+    all_tuples = (isinstance(arg, tuple) for arg in args)
+    if not all(all_tuples):
+        raise TypeError(
+            f"{param} must be a list of tuples "
+            "when the columns are a MultiIndex."
+        )
+
+    not_found = set(args).difference(indexer)
+    if any(not_found):
+        raise KeyError(
+            f"Tuples {*not_found,} in the {param} "
+            "argument do not exist in the dataframe's columns."
+        )
+
+    return args
