@@ -1,3 +1,4 @@
+"""Implementation of remove_empty."""
 import pandas_flavor as pf
 import pandas as pd
 
@@ -6,7 +7,7 @@ import pandas as pd
 def remove_empty(df: pd.DataFrame) -> pd.DataFrame:
     """Drop all rows and columns that are completely null.
 
-    This method also resets the index(by default) since it doesn't make sense
+    This method also resets the index (by default) since it doesn't make sense
     to preserve the index of a completely empty row.
 
     This method mutates the original DataFrame.
@@ -15,19 +16,25 @@ def remove_empty(df: pd.DataFrame) -> pd.DataFrame:
 
     [so]: https://stackoverflow.com/questions/38884538/python-pandas-find-all-rows-where-all-values-are-nan
 
-    Functional usage syntax:
+    Example:
 
-    ```python
-    df = remove_empty(df)
-    ```
-
-    Method chaining syntax:
-
-    ```python
-    import pandas as pd
-    import janitor
-    df = pd.DataFrame(...).remove_empty()
-    ```
+        >>> import numpy as np
+        >>> import pandas as pd
+        >>> import janitor
+        >>> df = pd.DataFrame({
+        ...     "a": [1, np.nan, 2],
+        ...     "b": [3, np.nan, 4],
+        ...     "c": [np.nan, np.nan, np.nan],
+        ... })
+        >>> df
+             a    b   c
+        0  1.0  3.0 NaN
+        1  NaN  NaN NaN
+        2  2.0  4.0 NaN
+        >>> df.remove_empty()
+             a    b
+        0  1.0  3.0
+        1  2.0  4.0
 
     :param df: The pandas DataFrame object.
     :returns: A pandas DataFrame.
