@@ -1,16 +1,20 @@
-""" Miscellaneous mathematical operators. """
+"""Miscellaneous mathematical operators.
+
+Lazy loading used here to speed up imports.
+"""
 
 import warnings
 from typing import Tuple
 
-import numpy as np
-import pandas as pd
-import pandas_flavor as pf
-from pandas.api.types import is_numeric_dtype
-from scipy.special import expit
-from scipy.special import logit as scipy_logit
-from scipy.special import softmax as scipy_softmax
-from scipy.stats import norm
+
+import lazy_loader as lazy
+
+scipy_special = lazy.load("scipy.special")
+ss = lazy.load("scipy.stats")
+pf = lazy.load("pandas_flavor")
+pd = lazy.load("pandas")
+np = lazy.load("numpy")
+pdtypes = lazy.load("pandas.api.types")
 
 
 @pf.register_series_method
@@ -94,7 +98,7 @@ def sigmoid(s: pd.Series) -> pd.Series:
     :param s: Input Series.
     :return: Transformed Series.
     """
-    return expit(s)
+    return scipy_special.expit(s)
 
 
 @pf.register_series_method
@@ -124,7 +128,8 @@ def softmax(s: pd.Series) -> pd.Series:
     :param s: Input Series.
     :return: Transformed Series.
     """
-    return scipy_softmax(s)
+
+    return pd.Series(scipy_special.softmax(s), index=s.index, name=s.name)
 
 
 @pf.register_series_method
@@ -167,7 +172,7 @@ def logit(s: pd.Series, error: str = "warn") -> pd.Series:
         else:
             pass
     s[outside_support] = np.nan
-    return scipy_logit(s)
+    return scipy_special.logit(s)
 
 
 @pf.register_series_method
@@ -187,7 +192,7 @@ def normal_cdf(s: pd.Series) -> pd.Series:
     :param s: Input Series.
     :return: Transformed Series.
     """
-    return pd.Series(norm.cdf(s), index=s.index)
+    return pd.Series(ss.norm.cdf(s), index=s.index)
 
 
 @pf.register_series_method
@@ -228,7 +233,7 @@ def probit(s: pd.Series, error: str = "warn") -> pd.Series:
             pass
     s[outside_support] = np.nan
     with np.errstate(all="ignore"):
-        out = pd.Series(norm.ppf(s), index=s.index)
+        out = pd.Series(ss.norm.ppf(s), index=s.index)
     return out
 
 
@@ -298,11 +303,11 @@ def ecdf(s: pd.Series) -> Tuple[np.ndarray, np.ndarray]:
 
         >>> import pandas as pd
         >>> import janitor
-        >>> df = pd.DataFrame({"numbers": [0, 4, 0, 1, 2, 1, 1, 3]})
-        >>> x, y = df["numbers"].ecdf()
-        >>> x
+        >>> s = pd.Series([0, 4, 0, 1, 2, 1, 1, 3])
+        >>> x, y = s.ecdf()
+        >>> x  # doctest: +SKIP
         array([0, 0, 1, 1, 1, 2, 3, 4])
-        >>> y
+        >>> y  # doctest: +SKIP
         array([0.125, 0.25 , 0.375, 0.5  , 0.625, 0.75 , 0.875, 1.   ])
 
     :param s: A pandas series. `dtype` should be numeric.
@@ -312,7 +317,7 @@ def ecdf(s: pd.Series) -> Tuple[np.ndarray, np.ndarray]:
     :raises TypeError: if series is not numeric.
     :raises ValueError: if series contains nulls.
     """
-    if not is_numeric_dtype(s):
+    if not pdtypes.is_numeric_dtype(s):
         raise TypeError(f"series {s.name} must be numeric!")
     if not s.isna().sum() == 0:
         raise ValueError(f"series {s.name} contains nulls. Please drop them.")
